@@ -80,9 +80,8 @@ class ReleaseLogIt:
 
     def __next__(self):
         if self.cur_pos < self.rel_cntr:
-            element = self.rel_notes[self.rel_list[self.cur_pos][0]][
-                self.rel_list[self.cur_pos][1]
-            ][self.rel_list[self.cur_pos][2]]
+            major, minor, patch = self.rel_list[self.cur_pos]
+            element = {major: {minor: {patch: self.rel_notes[major][minor][patch]}}}
             self.cur_pos += 1
             return element
         else:
@@ -115,7 +114,8 @@ class ReleaseLogIt:
             self.rel_list.append([major, minor, patch])
             self._sort()
             self.rel_cntr = len(self.rel_list)
-        return True
+            return True
+        return False
 
     def _create_def_config(self):
         """Create the "release.toml" configuration file.
@@ -172,6 +172,9 @@ class ReleaseLogIt:
             self.rel_list[-1][2]
         ]
 
+    def latest_version(self):
+        return f"{self.rel_list[-1][0]}.{self.rel_list[-1][1]}.{self.rel_list[-1][2]}"
+
     def oldest(self):
         return self.rel_notes[self.rel_list[0][0]][self.rel_list[0][1]][
             self.rel_list[0][2]
